      Program Deg2Km

! Given a lat and long, computes km N and E of a reference point

! Sample input (col. 1 starts after the initial "*")

!Name of output file:
!  deg2km.out
!Coordinates (title, ref. coord. (-west), n, e dist to point (km)):
!  JAB
! 34.31100 -118.49667  Ref for JAB
! 34.31151 -118.49665  coords of JAB
!  JGB 
! 34.31311 -118.49914  Ref for JGB
! 34.31299 -118.49884  coords of JGB
! stop


! Dates: 12/06/98 - Written by D.M. Boore, based on deg2km
!        12/18/98 - Appended version of deg2km_f modified to
!                   allow for negative latitudes
!        09/16/00 - removed double precision;
!                   assume -1. for sign of west longitude
!        04/30/02 - suggest default control filename
!        11/18/15 - Some modernization of code

      character buf*70, f_in*30, f_out*30
      real vn, ve, alat_ref, along_ref, vlat, vlong

      logical f_in_exist

      f_in_exist = .false.
      do while (.not. f_in_exist)
        f_in = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr = DEG2KM.CTL;'//
     :    ' CTL-BRK to quit): '
        read(*, '(a)') f_in
        if (f_in(1:4) == '    ') f_in = 'deg2km.ctl'
        call trim_c(f_in, nc_f_in)
        inquire(file=f_in(1:nc_f_in), exist=f_in_exist)
        if (.not. f_in_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do
      call get_lun(nu_in)
      open(nu_in, file=f_in(1:nc_f_in), status = 'unknown')
      write(*, '(1x,a)') f_in(1:nc_f_in)

! Obtain info from control file:

      read(nu_in,*)                            ! skip comment line
      f_out = ' '
      read(nu_in, '(a)') f_out
      call trim_c(f_out, nc_f_out)
      call get_lun(nu_out)
      open(nu_out, file=f_out(1:nc_f_out), status = 'unknown')
      
      read(nu_in,*)                            ! skip comment line

      loop_over_input: DO

        buf = ' '
        read(nu_in, '(a)') buf                   ! read title or stop
        call trim_c(buf, nc_buf)
        write(*, '(1x,a)') buf(1:nc_buf)
        write(nu_out,*)
        write(nu_out,'(a)') buf(1:nc_buf)
        call upstr(buf(1:nc_buf))
        if(buf(1:4) == 'STOP') then
          close(nu_in)
          close(nu_out)
          stop
        end if
        
        read(nu_in,*) alat_ref, along_ref        ! reference coordinates
        read(nu_in,*) vlat, vlong                ! coords of point

        call deg2km_f( vlat, vlong, alat_ref, along_ref, vn, ve )
        
        write(nu_out,'(a,2(1x,f10.5))') ' Ref. lat, long. = ',
     :     alat_ref, along_ref
        
        write(nu_out,'(a,2(1x,f10.5))') ' vlat, vlong = ', 
     :   vlat, vlong

        write(nu_out,'(a,3(1x,f10.5))') 
     :   ' Using Richter tables: Distance north, east, dist (km) = ',
     :   vn, ve, sqrt(vn**2 + ve**2)

        pi = 4.0*atan(1.0)
        d2r = pi/180.0
        
        vn = (vlat - alat_ref)*d2r*6371.0
        ve = (vlong - along_ref)*d2r*cos(0.5*(vlat+alat_ref)*d2r)*6371.0
        write(nu_out,'(a,3(1x,f10.5))') 
     :   ' Using sphere approx : Distance north, east, dist (km) = ',
     :   vn, ve, sqrt(vn**2 + ve**2)

      END DO loop_over_input


      end

      include '\forprogs\deg2km_f.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\locate.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\upstr.for'

